from setuptools import setup

setup(
  name='nampi',
  version='0.0.2',
  author='lalala',
  author_email='vikki.flove@gmail.com',
  description='///',
  long_description='///',
  long_description_content_type='text/markdown',
  url='https://github.com/Vika-K228',
  packages= ['scpy'],
  python_requires='>=3.0'
)